@@ -316,7 +316,7 @@ class AtomDance(object):
              self.zmat_id,self.zmat_index = add_zmat_atom(third,second,first,
                                   self.neighbors,self.zmat_id,self.zmat_index)
 
-  def zmat_to_cartation(self,atoms,zmat,traj=None):
+  def zmat_to_cartation(self,atoms,zmat):
       for i in range(len(self.zmat_id)):
           atomi = self.zmat_id[i]
           atomj = self.zmat_index[i][0]
@@ -333,9 +333,6 @@ class AtomDance(object):
              atoms = self.rotate_atom(atoms,atomi,atomj,atomk,atoml,r=r,ang=ang)
           else:
              atoms = self.rotate_atom(atoms,atomi,atomj,atomk,atoml,r=r,ang=ang,tor=tor)
-      if not traj is None:
-         traj.write(atoms=atoms)
-         traj.close()
       return atoms
 
   def stretch_atom(self,i,j,r,atoms):
