@@ -276,21 +276,22 @@ class LearningMachine(object):
                 elif learnWay == 5:
                    if ms<self.natom:
                       i = self.a.zmat_id[ms]
-                      j = self.a.zmat_id[ms+1]
                       if i not in self.freeatoms: 
                          self.freeatoms.append(i)
                          for i_ in self.a.neighbors[i]:
                              if len(self.a.neighbors[i_])==1:
                                 if i_ not in self.freeatoms: 
                                    self.freeatoms.append(i_)
-                      if j not in self.freeatoms: 
-                         self.freeatoms.append(j)
-                         for j_ in self.a.neighbors[j]:
-                             if len(self.a.neighbors[j_])==1:
-                                if j_ not in self.freeatoms: 
-                                   self.freeatoms.append(j_)
+                      # if j not in self.freeatoms: 
+                      #    self.freeatoms.append(j)
+                      #    for j_ in self.a.neighbors[j]:
+                      #        if len(self.a.neighbors[j_])==1:
+                      #           if j_ not in self.freeatoms: 
+                      #              self.freeatoms.append(j_)
                       self.save_config()
-                      atoms = self.a.set_bond_momenta(i,j,atoms)
+                      if ms+1<self.natom:
+                         j = self.a.zmat_id[ms+1]
+                         atoms = self.a.set_bond_momenta(i,j,atoms)
                    learnWay = 4
                 learnWay  = 2
                 ms       += 1
