@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 from .mdtodata import MDtoData
-from os import getcwd
+from os import getcwd,mkdir
+from os.path import exists
 from ase.io.trajectory import TrajectoryWriter,Trajectory
 from math import ceil
 import numpy as np
@@ -54,6 +55,9 @@ def prep_data(label=None,direcs=None,split_batch=100,frame=50,max_batch=50,dft='
        ind_   = np.linspace(0,nframe-1,num=n*split_batch,dtype=np.int32)
        images = [images[_] for _ in ind_]
 
+    if not exists('data'):
+       mkdir('data')
+
     trajs = {}
     for i in range(n):
         sf = i*split_batch
@@ -64,11 +68,12 @@ def prep_data(label=None,direcs=None,split_batch=100,frame=50,max_batch=50,dft='
            # print(i,sf,ef)
            images_ = images[sf:ef]
            tn      = label+'-'+str(i)
-           traj    = TrajectoryWriter(tn+'.traj',mode='w')
+           tn_     = 'data/'+tn +'.traj'
+           traj    = TrajectoryWriter(tn_,mode='w')
            for atoms in images_:
                traj.write(atoms=atoms)
            traj.close()
-           trajs[tn] = tn+'.traj'
+           trajs[tn] = tn_
     return trajs
 
 
