@@ -117,7 +117,7 @@ class IRFF(Calculator):
          self.EnergyFunction = j['EnergyFunction']
          self.MessageFunction= j['MessageFunction']
          self.bo_layer       = j['bo_layer']
-         self.bf_layer       = j['bf_layer']
+         self.mf_layer       = j['mf_layer']
          self.be_layer       = j['be_layer']
          self.vdw_layer      = j['vdw_layer']
          lf.close()
@@ -366,7 +366,7 @@ class IRFF(Calculator):
           Dbi        = Di_ - self.H[t-1]
           Dbj        = Dj_ - self.H[t-1]
 
-          Fi    = self.f_nn('f'+str(t),[Dbj,Dbi,self.H[t-1]],layer=self.bf_layer[1])
+          Fi    = self.f_nn('f'+str(t),[Dbj,Dbi,self.H[t-1]],layer=self.mf_layer[1])
           Fj    = torch.transpose(Fi,0,1)
           F     = 2.0*Fi*Fj
 
@@ -1149,7 +1149,7 @@ class IRFF(Calculator):
               elif k_ =='fv':
                  layer_ = self.vdw_layer[1]
               else:
-                 layer_ = self.bf_layer[1]
+                 layer_ = self.mf_layer[1]
 
               for l in range(layer_):
                   m_ = []
