@@ -108,7 +108,7 @@ class IRFF_NP(object):
          self.EnergyFunction = j['EnergyFunction']
          self.MessageFunction= j['MessageFunction']
          self.bo_layer = j['bo_layer']
-         self.bf_layer = j['bf_layer']
+         self.mf_layer = j['mf_layer']
          self.be_layer = j['be_layer']
          self.vdw_layer = j['vdw_layer']
          
@@ -361,8 +361,8 @@ class IRFF_NP(object):
           Dbi        = Di_ - self.H[t-1]
           Dbj        = Dj_ - self.H[t-1]
 
-          # self.Fi  = self.f_nn('f',[Di,Dj,Dbi,Dbj],layer=self.bf_layer[1])
-          Fi    = self.f_nn('f'+str(t),[Dbj,Dbi,self.H[t-1]],layer=self.bf_layer[1])
+          # self.Fi  = self.f_nn('f',[Di,Dj,Dbi,Dbj],layer=self.mf_layer[1])
+          Fi    = self.f_nn('f'+str(t),[Dbj,Dbi,self.H[t-1]],layer=self.mf_layer[1])
 
 
           if self.MessageFunction==1:
@@ -863,7 +863,7 @@ class IRFF_NP(object):
          self.EnergyFunction = j['EnergyFunction']
          self.MessageFunction= j['MessageFunction']
          self.bo_layer = j['bo_layer']
-         self.bf_layer = j['bf_layer']
+         self.mf_layer = j['mf_layer']
          self.be_layer = j['be_layer']
          self.vdw_layer  = j['vdw_layer']
          lf.close()
@@ -1162,7 +1162,7 @@ class IRFF_NP(object):
               elif k_ =='fv':
                  layer_ = self.vdw_layer[1]
               else:
-                 layer_ = self.bf_layer[1]
+                 layer_ = self.mf_layer[1]
 
               for l in range(layer_):
                   m_ = []
