@@ -41,7 +41,8 @@ class IRMD(object):
                initT=300,Tmax=10000,time_step=0.1,Iter=0,
                ro=None,rmin=0.6,rmax=1.3,angmax=20.0,
                UseZmat=False,zmat_id=None,zmat_index=None,InitZmat=None,
-               dEstop=0.5):
+               dEstop=0.5,
+               print_interval=1):
       self.Epot    = []
       self.epot    = 0.0
       self.ekin    = 0.0
@@ -63,6 +64,7 @@ class IRMD(object):
       self.InitZmat  = InitZmat
       self.zmats     = []
       self.dEstop    = dEstop
+      self.print_interval = print_interval
 
       if self.atoms is None:
          self.atoms  = read(gen,index=index)
@@ -157,7 +159,7 @@ class IRMD(object):
              self.dyn.max_steps = self.dyn.nsteps-1
   
       # traj = Trajectory('md.traj', 'w', self.atoms)
-      self.dyn.attach(printenergy,interval=1)
+      self.dyn.attach(printenergy,interval=self.print_interval)
       # self.dyn.attach(traj.write,interval=1)
       self.dyn.run(self.totstep)
       return self.Deformed,self.zmats,self.zv,self.zvlo,self.zvhi
