@@ -502,7 +502,9 @@ class ReaxFF(object):
           sum_edft = tf.reduce_sum(input_tensor=tf.abs(self.dft_energy[mol]-self.zpe[mol])) # self.max_e[mol]
           self.accur[mol] = 1.0 - tf.reduce_sum(input_tensor=tf.abs(self.E[mol]-self.dft_energy[mol]))/(sum_edft+0.00000001)
           
-          if mol_ in self.weight:
+          if mol in self.weight:
+             self.Loss     += self.loss[mol]*self.weight[mol]
+          elif mol_ in self.weight:
              self.Loss     += self.loss[mol]*self.weight[mol_]
           else:
              self.Loss     += self.loss[mol]
@@ -1278,7 +1280,7 @@ class ReaxFF(object):
           elif key=='ovun5':
              self.p[k] = tf.clip_by_value(self.v[k],0.0,999.0*self.unit)
           elif key=='ovun1':
-             self.p[k] = tf.clip_by_value(self.v[k],0.2,99.0)
+             self.p[k] = tf.clip_by_value(self.v[k],0.1,1.2)
           elif key in ['boc4','boc5','vdw1']:
              self.p[k] = tf.clip_by_value(self.v[k],0.00000001,100.0)
           elif key == 'boc3':
@@ -1842,7 +1844,7 @@ class ReaxFF(object):
               'MessageFunction':1, 
               'messages':1,
               'bo_layer':None,
-              'bf_layer':None,
+              'mf_layer':None,
               'be_layer':None,
               'vdw_layer':None,
               'MolEnergy':self.MolEnergy_}
@@ -1865,7 +1867,7 @@ class ReaxFF(object):
          self.MessageFunction_ = j['MessageFunction']
          self.MolEnergy_       = j['MolEnergy']
          self.bo_layer_        = j['bo_layer']
-         self.bf_layer_        = j['bf_layer']
+         self.mf_layer_        = j['mf_layer']
          self.be_layer_        = j['be_layer']
          self.vdw_layer_       = j['vdw_layer']
          self.init_bonds()
