@@ -24,7 +24,7 @@ def train(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence=1000
           spec=[],
           writelib=1000,nn=True,vdwnn=False,mefac=0.1,
           bo_layer=[3,1],
-          bf_layer=[9,2],
+          mf_layer=[9,2],
           be_layer=[3,1],
           EnergyFunction=3,MessageFunction=2,mpopt=3,
           bore={'others':0.45},
@@ -87,11 +87,13 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
           spec=[],
           writelib=1000,nn=True,vdwnn=False,
           bo_layer=[3,1],
-          bf_layer=[9,2],
+          mf_layer=[9,2],
           be_layer=[3,1],
           EnergyFunction=3,MessageFunction=2,mpopt=3,
           bore={'others':0.45},
           bom={'others':1.0},
+          spv_bm=False,
+          spv_be=False,
           mefac=0.1,
           weight={'others':10.0},
           bo_penalty=10000.0,
@@ -117,7 +119,7 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
                 opt=opt_,
                 nn=nn,vdwnn=vdwnn,
                 bo_layer=bo_layer,
-                bf_layer=bf_layer,
+                mf_layer=mf_layer,
                 be_layer=be_layer,
                 EnergyFunction=EnergyFunction,
                 MessageFunction=MessageFunction,
@@ -128,7 +130,7 @@ def train_mpnn(direcs=None,step=5000,batch=None,convergence=0.97,lossConvergence
                 losFunc='n2',
                 bo_penalty=bo_penalty,
                 nanv=nanv,
-                bom=bom,bore=bore,
+                bom=bom,bore=bore,spv_bm=spv_bm,spv_be=spv_be,
                 weight=weight,mefac=mefac,
                 convergence=convergence,
                 lossConvergence=lossConvergence) # Loss Functon can be n2,abs,mse,huber
